@@ -10,11 +10,11 @@ Crypt::LE - Let's Encrypt API interfacing module.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -50,7 +50,7 @@ be used to generate RSA keys and Certificate Signing Requests.
 Crypt::LE can be easily extended with custom plugins to handle Let's Encrypt challenges. See L<Crypt::LE::Challenge::Simple> module
 as an example of such plugin.
 
-Crypt::LE is shipped with a self-sufficient client for obtaining SSL certificates - L<le.pl>.
+Crypt::LE is shipped with a self-sufficient client for obtaining SSL certificates - I<le.pl>.
 
 Usage example: le.pl --key account.key --csr domain.csr --csr-key domain.key --crt domain.crt --domains "www.domain.ext,domain.ext" --generate-missing
 
@@ -76,7 +76,10 @@ LOAD_ERROR
 INVALID_DATA
 
 =item *
-DATA_MISMATCH ERROR
+DATA_MISMATCH 
+
+=item *
+ERROR
 
 =back
 
