@@ -17,7 +17,7 @@ GetOptions ("key=s" => \$account_key, "csr=s" => \$csr, "csr-key=s" => \$csr_key
 
 my $usage = <<EOF;
 
-Usage example: $0 --key account.key --csr domain.csr --csr-key domain.key --crt domain.crt --domains "www.domain.ext,domain.ext" --generate-missing
+Usage example: le.pl --key account.key --csr domain.csr --csr-key domain.key --crt domain.crt --domains "www.domain.ext,domain.ext" --generate-missing
 
 Note: by default a staging server is used, which does not provide trusted certificates. This is to aviod hitting a rate limits on Let's Encrypt
       live server. To generate an actual certificate, always add --live option.
